# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class JobAllocations(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allocated_circuits': 'list[Allocation]',
        'input_parameters': 'CompilationParameters',
        'language': 'str',
        'runtime': 'float'
    }

    attribute_map = {
        'allocated_circuits': 'allocatedCircuits',
        'input_parameters': 'inputParameters',
        'language': 'language',
        'runtime': 'runtime'
    }

    def __init__(self, allocated_circuits=None, input_parameters=None, language=None, runtime=None, local_vars_configuration=None):  # noqa: E501
        """JobAllocations - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allocated_circuits = None
        self._input_parameters = None
        self._language = None
        self._runtime = None
        self.discriminator = None

        if allocated_circuits is not None:
            self.allocated_circuits = allocated_circuits
        self.input_parameters = input_parameters
        if language is not None:
            self.language = language
        if runtime is not None:
            self.runtime = runtime

    @property
    def allocated_circuits(self):
        """Gets the allocated_circuits of this JobAllocations.  # noqa: E501


        :return: The allocated_circuits of this JobAllocations.  # noqa: E501
        :rtype: list[Allocation]
        """
        return self._allocated_circuits

    @allocated_circuits.setter
    def allocated_circuits(self, allocated_circuits):
        """Sets the allocated_circuits of this JobAllocations.


        :param allocated_circuits: The allocated_circuits of this JobAllocations.  # noqa: E501
        :type: list[Allocation]
        """

        self._allocated_circuits = allocated_circuits

    @property
    def input_parameters(self):
        """Gets the input_parameters of this JobAllocations.  # noqa: E501


        :return: The input_parameters of this JobAllocations.  # noqa: E501
        :rtype: CompilationParameters
        """
        return self._input_parameters

    @input_parameters.setter
    def input_parameters(self, input_parameters):
        """Sets the input_parameters of this JobAllocations.


        :param input_parameters: The input_parameters of this JobAllocations.  # noqa: E501
        :type: CompilationParameters
        """
        if self.local_vars_configuration.client_side_validation and input_parameters is None:  # noqa: E501
            raise ValueError("Invalid value for `input_parameters`, must not be `None`")  # noqa: E501

        self._input_parameters = input_parameters

    @property
    def language(self):
        """Gets the language of this JobAllocations.  # noqa: E501


        :return: The language of this JobAllocations.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this JobAllocations.


        :param language: The language of this JobAllocations.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def runtime(self):
        """Gets the runtime of this JobAllocations.  # noqa: E501

        the runtume of the optimizatin compilation in milliseconds  # noqa: E501

        :return: The runtime of this JobAllocations.  # noqa: E501
        :rtype: float
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """Sets the runtime of this JobAllocations.

        the runtume of the optimizatin compilation in milliseconds  # noqa: E501

        :param runtime: The runtime of this JobAllocations.  # noqa: E501
        :type: float
        """

        self._runtime = runtime

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobAllocations):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobAllocations):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class ResultsData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'empirical_sso': 'float',
        'end_datetime': 'str',
        'measurements': 'ResultsDataMeasurements',
        'runtime': 'float',
        'start_datetime': 'str'
    }

    attribute_map = {
        'empirical_sso': 'empiricalSso',
        'end_datetime': 'endDatetime',
        'measurements': 'measurements',
        'runtime': 'runtime',
        'start_datetime': 'startDatetime'
    }

    def __init__(self, empirical_sso=None, end_datetime=None, measurements=None, runtime=None, start_datetime=None, local_vars_configuration=None):  # noqa: E501
        """ResultsData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._empirical_sso = None
        self._end_datetime = None
        self._measurements = None
        self._runtime = None
        self._start_datetime = None
        self.discriminator = None

        if empirical_sso is not None:
            self.empirical_sso = empirical_sso
        if end_datetime is not None:
            self.end_datetime = end_datetime
        if measurements is not None:
            self.measurements = measurements
        if runtime is not None:
            self.runtime = runtime
        if start_datetime is not None:
            self.start_datetime = start_datetime

    @property
    def empirical_sso(self):
        """Gets the empirical_sso of this ResultsData.  # noqa: E501


        :return: The empirical_sso of this ResultsData.  # noqa: E501
        :rtype: float
        """
        return self._empirical_sso

    @empirical_sso.setter
    def empirical_sso(self, empirical_sso):
        """Sets the empirical_sso of this ResultsData.


        :param empirical_sso: The empirical_sso of this ResultsData.  # noqa: E501
        :type: float
        """

        self._empirical_sso = empirical_sso

    @property
    def end_datetime(self):
        """Gets the end_datetime of this ResultsData.  # noqa: E501


        :return: The end_datetime of this ResultsData.  # noqa: E501
        :rtype: str
        """
        return self._end_datetime

    @end_datetime.setter
    def end_datetime(self, end_datetime):
        """Sets the end_datetime of this ResultsData.


        :param end_datetime: The end_datetime of this ResultsData.  # noqa: E501
        :type: str
        """

        self._end_datetime = end_datetime

    @property
    def measurements(self):
        """Gets the measurements of this ResultsData.  # noqa: E501


        :return: The measurements of this ResultsData.  # noqa: E501
        :rtype: ResultsDataMeasurements
        """
        return self._measurements

    @measurements.setter
    def measurements(self, measurements):
        """Sets the measurements of this ResultsData.


        :param measurements: The measurements of this ResultsData.  # noqa: E501
        :type: ResultsDataMeasurements
        """

        self._measurements = measurements

    @property
    def runtime(self):
        """Gets the runtime of this ResultsData.  # noqa: E501

        This is the duration of all pirate runs in milliseconds. This differs from start and end datetime, because the datetimes indicate the beginning of the  first run   to the end of the last run.   # noqa: E501

        :return: The runtime of this ResultsData.  # noqa: E501
        :rtype: float
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """Sets the runtime of this ResultsData.

        This is the duration of all pirate runs in milliseconds. This differs from start and end datetime, because the datetimes indicate the beginning of the  first run   to the end of the last run.   # noqa: E501

        :param runtime: The runtime of this ResultsData.  # noqa: E501
        :type: float
        """

        self._runtime = runtime

    @property
    def start_datetime(self):
        """Gets the start_datetime of this ResultsData.  # noqa: E501


        :return: The start_datetime of this ResultsData.  # noqa: E501
        :rtype: str
        """
        return self._start_datetime

    @start_datetime.setter
    def start_datetime(self, start_datetime):
        """Sets the start_datetime of this ResultsData.


        :param start_datetime: The start_datetime of this ResultsData.  # noqa: E501
        :type: str
        """

        self._start_datetime = start_datetime

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResultsData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResultsData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class CredentialsVendor(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aqt': 'CredentialsAqt',
        'ibm': 'CredentialsIbm',
        'honeywell': 'CredentialsHoneywell',
        'rigetti': 'CredentialsRigetti'
    }

    attribute_map = {
        'aqt': 'aqt',
        'ibm': 'ibm',
        'honeywell': 'honeywell',
        'rigetti': 'rigetti'
    }

    def __init__(self, aqt=None, ibm=None, honeywell=None, rigetti=None, local_vars_configuration=None):  # noqa: E501
        """CredentialsVendor - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._aqt = None
        self._ibm = None
        self._honeywell = None
        self._rigetti = None
        self.discriminator = None

        if aqt is not None:
            self.aqt = aqt
        if ibm is not None:
            self.ibm = ibm
        if honeywell is not None:
            self.honeywell = honeywell
        if rigetti is not None:
            self.rigetti = rigetti

    @property
    def aqt(self):
        """Gets the aqt of this CredentialsVendor.  # noqa: E501


        :return: The aqt of this CredentialsVendor.  # noqa: E501
        :rtype: CredentialsAqt
        """
        return self._aqt

    @aqt.setter
    def aqt(self, aqt):
        """Sets the aqt of this CredentialsVendor.


        :param aqt: The aqt of this CredentialsVendor.  # noqa: E501
        :type: CredentialsAqt
        """

        self._aqt = aqt

    @property
    def ibm(self):
        """Gets the ibm of this CredentialsVendor.  # noqa: E501


        :return: The ibm of this CredentialsVendor.  # noqa: E501
        :rtype: CredentialsIbm
        """
        return self._ibm

    @ibm.setter
    def ibm(self, ibm):
        """Sets the ibm of this CredentialsVendor.


        :param ibm: The ibm of this CredentialsVendor.  # noqa: E501
        :type: CredentialsIbm
        """

        self._ibm = ibm

    @property
    def honeywell(self):
        """Gets the honeywell of this CredentialsVendor.  # noqa: E501


        :return: The honeywell of this CredentialsVendor.  # noqa: E501
        :rtype: CredentialsHoneywell
        """
        return self._honeywell

    @honeywell.setter
    def honeywell(self, honeywell):
        """Sets the honeywell of this CredentialsVendor.


        :param honeywell: The honeywell of this CredentialsVendor.  # noqa: E501
        :type: CredentialsHoneywell
        """

        self._honeywell = honeywell

    @property
    def rigetti(self):
        """Gets the rigetti of this CredentialsVendor.  # noqa: E501


        :return: The rigetti of this CredentialsVendor.  # noqa: E501
        :rtype: CredentialsRigetti
        """
        return self._rigetti

    @rigetti.setter
    def rigetti(self, rigetti):
        """Sets the rigetti of this CredentialsVendor.


        :param rigetti: The rigetti of this CredentialsVendor.  # noqa: E501
        :type: CredentialsRigetti
        """

        self._rigetti = rigetti

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CredentialsVendor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CredentialsVendor):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import openapi_client
from openapi_client.models.device_list_response import DeviceListResponse  # noqa: E501
from openapi_client.rest import ApiException

class TestDeviceListResponse(unittest.TestCase):
    """DeviceListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DeviceListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = openapi_client.models.device_list_response.DeviceListResponse()  # noqa: E501
        if include_optional :
            return DeviceListResponse(
                data = openapi_client.models.owner_details.OwnerDetails(
                    owners = {
                        'key' : openapi_client.models.owner_details_owners.OwnerDetails_owners(
                            devices = {
                                'key' : openapi_client.models.device_details.DeviceDetails(
                                    device_id = '0', 
                                    display_name = '0', 
                                    gates = [
                                        openapi_client.models.gate.Gate(
                                            fidelity = 1.337, 
                                            qubit_from = openapi_client.models.qubit.Qubit(
                                                fidelity_rotation = 1.337, 
                                                last_reported_fidelity_rotation_datetime = '0', 
                                                name = 56, 
                                                pos_x = 1.337, 
                                                pos_y = 1.337, 
                                                real_qubit = 56, ), 
                                            qubit_to = openapi_client.models.qubit.Qubit(
                                                fidelity_rotation = 1.337, 
                                                last_reported_fidelity_rotation_datetime = '0', 
                                                name = 56, 
                                                pos_x = 1.337, 
                                                pos_y = 1.337, 
                                                real_qubit = 56, ), 
                                            gate_type = '0', )
                                        ], 
                                    is_simulator = True, 
                                    last_calibration = '0', 
                                    max_shots = 56, 
                                    next_available_time = '0', 
                                    price = 1.337, 
                                    t1 = 1.337, 
                                    t2 = 1.337, )
                                }, )
                        }, )
            )
        else :
            return DeviceListResponse(
        )

    def testDeviceListResponse(self):
        """Test DeviceListResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from dataclasses import dataclass
import json
from typing import Any, Callable

from aliro_quantum import ApiClient
import sseclient


@dataclass
class FakeResponse:
    data: Any


class StreamingApiClient:
    def __init__(self,
                 api_client: ApiClient):
        self._api_client = api_client

    def stream_response(self,
                        response_function: Callable,
                        response_class: type,
                        **kwargs):
        # Wait for results
        response = response_function(_preload_content=False,
                                     **kwargs)

        client = sseclient.SSEClient(response)
        for event in client.events():
            response_data = json.loads(event.data)['data']
            yield self._api_client.deserialize(
                FakeResponse(data=response_data),
                response_class)



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import openapi_client
from openapi_client.models.pid_response import PidResponse  # noqa: E501
from openapi_client.rest import ApiException

class TestPidResponse(unittest.TestCase):
    """PidResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PidResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = openapi_client.models.pid_response.PidResponse()  # noqa: E501
        if include_optional :
            return PidResponse(
                pid = '0'
            )
        else :
            return PidResponse(
        )

    def testPidResponse(self):
        """Test PidResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import openapi_client
from openapi_client.models.job import Job  # noqa: E501
from openapi_client.rest import ApiException

class TestJob(unittest.TestCase):
    """Job unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Job
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = openapi_client.models.job.Job()  # noqa: E501
        if include_optional :
            return Job(
                allocations = openapi_client.models.job_allocations.Job_allocations(
                    allocated_circuits = [
                        openapi_client.models.allocation.Allocation(
                            allocated_qubits = [
                                56
                                ], 
                            depth = 56, 
                            program = '0', 
                            num_gates_double = 56, 
                            num_gates_single = 56, 
                            num_measurements = 56, 
                            num_swaps = 56, )
                        ], 
                    input_parameters = openapi_client.models.compilation_parameters.CompilationParameters(
                        compilation_type = '0', 
                        num_allocations = 56, ), 
                    language = '0', 
                    runtime = 1.337, ), 
                cancelling = True, 
                costs = openapi_client.models.job_costs.Job_costs(
                    reservation = 1.337, ), 
                errors = [
                    openapi_client.models.job_errors.Job_errors(
                        error_code = '0', 
                        error_message = '0', )
                    ], 
                execution = openapi_client.models.job_execution.Job_execution(
                    parameters = openapi_client.models.execution_parameters.ExecutionParameters(
                        num_shots = 56, 
                        output_type = '0', ), 
                    results = openapi_client.models.execution_results.ExecutionResults(
                        real = openapi_client.models.results_data.ResultsData(
                            empirical_sso = 1.337, 
                            end_datetime = '0', 
                            measurements = openapi_client.models.results_data_measurements.ResultsData_measurements(
                                raw = [
                                    [
                                        [
                                            56
                                            ]
                                        ]
                                    ], 
                                weighted_combination = {
                                    'key' : 1.337
                                    }, ), 
                            runtime = 1.337, 
                            start_datetime = '0', ), 
                        simulated = openapi_client.models.results_data.ResultsData(
                            empirical_sso = 1.337, 
                            end_datetime = '0', 
                            runtime = 1.337, 
                            start_datetime = '0', ), ), ), 
                id = '0', 
                reservation = openapi_client.models.reservation.Reservation(
                    end_datetime = '0', 
                    id = '0', 
                    price = 1.337, 
                    start_datetime = '0', 
                    their_id = '0', ), 
                target = openapi_client.models.owner_details.OwnerDetails(
                    owners = {
                        'key' : openapi_client.models.owner_details_owners.OwnerDetails_owners(
                            devices = {
                                'key' : openapi_client.models.device_details.DeviceDetails(
                                    device_id = '0', 
                                    display_name = '0', 
                                    gates = [
                                        openapi_client.models.gate.Gate(
                                            fidelity = 1.337, 
                                            qubit_from = openapi_client.models.qubit.Qubit(
                                                fidelity_rotation = 1.337, 
                                                last_reported_fidelity_rotation_datetime = '0', 
                                                name = 56, 
                                                pos_x = 1.337, 
                                                pos_y = 1.337, 
                                                real_qubit = 56, ), 
                                            qubit_to = openapi_client.models.qubit.Qubit(
                                                fidelity_rotation = 1.337, 
                                                last_reported_fidelity_rotation_datetime = '0', 
                                                name = 56, 
                                                pos_x = 1.337, 
                                                pos_y = 1.337, 
                                                real_qubit = 56, ), 
                                            gate_type = '0', )
                                        ], 
                                    is_simulator = True, 
                                    last_calibration = '0', 
                                    max_shots = 56, 
                                    next_available_time = '0', 
                                    price = 1.337, 
                                    t1 = 1.337, 
                                    t2 = 1.337, )
                                }, )
                        }, )
            )
        else :
            return Job(
                allocations = openapi_client.models.job_allocations.Job_allocations(
                    allocated_circuits = [
                        openapi_client.models.allocation.Allocation(
                            allocated_qubits = [
                                56
                                ], 
                            depth = 56, 
                            program = '0', 
                            num_gates_double = 56, 
                            num_gates_single = 56, 
                            num_measurements = 56, 
                            num_swaps = 56, )
                        ], 
                    input_parameters = openapi_client.models.compilation_parameters.CompilationParameters(
                        compilation_type = '0', 
                        num_allocations = 56, ), 
                    language = '0', 
                    runtime = 1.337, ),
                execution = openapi_client.models.job_execution.Job_execution(
                    parameters = openapi_client.models.execution_parameters.ExecutionParameters(
                        num_shots = 56, 
                        output_type = '0', ), 
                    results = openapi_client.models.execution_results.ExecutionResults(
                        real = openapi_client.models.results_data.ResultsData(
                            empirical_sso = 1.337, 
                            end_datetime = '0', 
                            measurements = openapi_client.models.results_data_measurements.ResultsData_measurements(
                                raw = [
                                    [
                                        [
                                            56
                                            ]
                                        ]
                                    ], 
                                weighted_combination = {
                                    'key' : 1.337
                                    }, ), 
                            runtime = 1.337, 
                            start_datetime = '0', ), 
                        simulated = openapi_client.models.results_data.ResultsData(
                            empirical_sso = 1.337, 
                            end_datetime = '0', 
                            runtime = 1.337, 
                            start_datetime = '0', ), ), ),
                target = openapi_client.models.owner_details.OwnerDetails(
                    owners = {
                        'key' : openapi_client.models.owner_details_owners.OwnerDetails_owners(
                            devices = {
                                'key' : openapi_client.models.device_details.DeviceDetails(
                                    device_id = '0', 
                                    display_name = '0', 
                                    gates = [
                                        openapi_client.models.gate.Gate(
                                            fidelity = 1.337, 
                                            qubit_from = openapi_client.models.qubit.Qubit(
                                                fidelity_rotation = 1.337, 
                                                last_reported_fidelity_rotation_datetime = '0', 
                                                name = 56, 
                                                pos_x = 1.337, 
                                                pos_y = 1.337, 
                                                real_qubit = 56, ), 
                                            qubit_to = openapi_client.models.qubit.Qubit(
                                                fidelity_rotation = 1.337, 
                                                last_reported_fidelity_rotation_datetime = '0', 
                                                name = 56, 
                                                pos_x = 1.337, 
                                                pos_y = 1.337, 
                                                real_qubit = 56, ), 
                                            gate_type = '0', )
                                        ], 
                                    is_simulator = True, 
                                    last_calibration = '0', 
                                    max_shots = 56, 
                                    next_available_time = '0', 
                                    price = 1.337, 
                                    t1 = 1.337, 
                                    t2 = 1.337, )
                                }, )
                        }, ),
        )

    def testJob(self):
        """Test Job"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import openapi_client
from openapi_client.models.translation_response import TranslationResponse  # noqa: E501
from openapi_client.rest import ApiException

class TestTranslationResponse(unittest.TestCase):
    """TranslationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TranslationResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = openapi_client.models.translation_response.TranslationResponse()  # noqa: E501
        if include_optional :
            return TranslationResponse(
                circuit = openapi_client.models.circuit.Circuit(
                    body = '0', 
                    depth = 56, 
                    jobs = [
                        openapi_client.models.job.Job(
                            allocations = openapi_client.models.job_allocations.Job_allocations(
                                allocated_circuits = [
                                    openapi_client.models.allocation.Allocation(
                                        allocated_qubits = [
                                            56
                                            ], 
                                        depth = 56, 
                                        program = '0', 
                                        num_gates_double = 56, 
                                        num_gates_single = 56, 
                                        num_measurements = 56, 
                                        num_swaps = 56, )
                                    ], 
                                input_parameters = openapi_client.models.compilation_parameters.CompilationParameters(
                                    compilation_type = '0', 
                                    num_allocations = 56, ), 
                                language = '0', 
                                runtime = 1.337, ), 
                            cancelling = True, 
                            costs = openapi_client.models.job_costs.Job_costs(
                                reservation = 1.337, ), 
                            errors = [
                                openapi_client.models.job_errors.Job_errors(
                                    error_code = '0', 
                                    error_message = '0', )
                                ], 
                            execution = openapi_client.models.job_execution.Job_execution(
                                parameters = openapi_client.models.execution_parameters.ExecutionParameters(
                                    num_shots = 56, 
                                    output_type = '0', ), 
                                results = openapi_client.models.execution_results.ExecutionResults(
                                    real = openapi_client.models.results_data.ResultsData(
                                        empirical_sso = 1.337, 
                                        end_datetime = '0', 
                                        measurements = openapi_client.models.results_data_measurements.ResultsData_measurements(
                                            raw = [
                                                [
                                                    [
                                                        56
                                                        ]
                                                    ]
                                                ], 
                                            weighted_combination = {
                                                'key' : 1.337
                                                }, ), 
                                        runtime = 1.337, 
                                        start_datetime = '0', ), 
                                    simulated = openapi_client.models.results_data.ResultsData(
                                        empirical_sso = 1.337, 
                                        end_datetime = '0', 
                                        runtime = 1.337, 
                                        start_datetime = '0', ), ), ), 
                            id = '0', 
                            reservation = openapi_client.models.reservation.Reservation(
                                end_datetime = '0', 
                                id = '0', 
                                price = 1.337, 
                                start_datetime = '0', 
                                their_id = '0', ), 
                            target = openapi_client.models.owner_details.OwnerDetails(
                                owners = {
                                    'key' : openapi_client.models.owner_details_owners.OwnerDetails_owners(
                                        devices = {
                                            'key' : openapi_client.models.device_details.DeviceDetails(
                                                device_id = '0', 
                                                display_name = '0', 
                                                gates = [
                                                    openapi_client.models.gate.Gate(
                                                        fidelity = 1.337, 
                                                        qubit_from = openapi_client.models.qubit.Qubit(
                                                            fidelity_rotation = 1.337, 
                                                            last_reported_fidelity_rotation_datetime = '0', 
                                                            name = 56, 
                                                            pos_x = 1.337, 
                                                            pos_y = 1.337, 
                                                            real_qubit = 56, ), 
                                                        qubit_to = openapi_client.models.qubit.Qubit(
                                                            fidelity_rotation = 1.337, 
                                                            last_reported_fidelity_rotation_datetime = '0', 
                                                            name = 56, 
                                                            pos_x = 1.337, 
                                                            pos_y = 1.337, 
                                                            real_qubit = 56, ), 
                                                        gate_type = '0', )
                                                    ], 
                                                is_simulator = True, 
                                                last_calibration = '0', 
                                                max_shots = 56, 
                                                next_available_time = '0', 
                                                price = 1.337, 
                                                t1 = 1.337, 
                                                t2 = 1.337, )
                                            }, )
                                    }, ), )
                        ], 
                    language = '0', 
                    name = '0', 
                    num_gates_double = 56, 
                    num_gates_single = 56, 
                    num_measurements = 56, 
                    num_swaps = 56, )
            )
        else :
            return TranslationResponse(
        )

    def testTranslationResponse(self):
        """Test TranslationResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from aliro_quantum.api.authentication_api import AuthenticationApi
from aliro_quantum.api.circuit_api import CircuitApi
from aliro_quantum.api.credentials_api import CredentialsApi
from aliro_quantum.api.device_rankings_api import DeviceRankingsApi
from aliro_quantum.api.info_api import InfoApi
from aliro_quantum.api.jobs_api import JobsApi
from aliro_quantum.api.submissions_api import SubmissionsApi



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class Qubit(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'fidelity_rotation': 'float',
        'last_reported_fidelity_rotation_datetime': 'str',
        'name': 'int',
        'pos_x': 'float',
        'pos_y': 'float',
        'real_qubit': 'int'
    }

    attribute_map = {
        'fidelity_rotation': 'fidelityRotation',
        'last_reported_fidelity_rotation_datetime': 'lastReportedFidelityRotationDatetime',
        'name': 'name',
        'pos_x': 'posX',
        'pos_y': 'posY',
        'real_qubit': 'realQubit'
    }

    def __init__(self, fidelity_rotation=None, last_reported_fidelity_rotation_datetime=None, name=None, pos_x=None, pos_y=None, real_qubit=None, local_vars_configuration=None):  # noqa: E501
        """Qubit - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._fidelity_rotation = None
        self._last_reported_fidelity_rotation_datetime = None
        self._name = None
        self._pos_x = None
        self._pos_y = None
        self._real_qubit = None
        self.discriminator = None

        if fidelity_rotation is not None:
            self.fidelity_rotation = fidelity_rotation
        if last_reported_fidelity_rotation_datetime is not None:
            self.last_reported_fidelity_rotation_datetime = last_reported_fidelity_rotation_datetime
        if name is not None:
            self.name = name
        if pos_x is not None:
            self.pos_x = pos_x
        if pos_y is not None:
            self.pos_y = pos_y
        if real_qubit is not None:
            self.real_qubit = real_qubit

    @property
    def fidelity_rotation(self):
        """Gets the fidelity_rotation of this Qubit.  # noqa: E501


        :return: The fidelity_rotation of this Qubit.  # noqa: E501
        :rtype: float
        """
        return self._fidelity_rotation

    @fidelity_rotation.setter
    def fidelity_rotation(self, fidelity_rotation):
        """Sets the fidelity_rotation of this Qubit.


        :param fidelity_rotation: The fidelity_rotation of this Qubit.  # noqa: E501
        :type: float
        """

        self._fidelity_rotation = fidelity_rotation

    @property
    def last_reported_fidelity_rotation_datetime(self):
        """Gets the last_reported_fidelity_rotation_datetime of this Qubit.  # noqa: E501


        :return: The last_reported_fidelity_rotation_datetime of this Qubit.  # noqa: E501
        :rtype: str
        """
        return self._last_reported_fidelity_rotation_datetime

    @last_reported_fidelity_rotation_datetime.setter
    def last_reported_fidelity_rotation_datetime(self, last_reported_fidelity_rotation_datetime):
        """Sets the last_reported_fidelity_rotation_datetime of this Qubit.


        :param last_reported_fidelity_rotation_datetime: The last_reported_fidelity_rotation_datetime of this Qubit.  # noqa: E501
        :type: str
        """

        self._last_reported_fidelity_rotation_datetime = last_reported_fidelity_rotation_datetime

    @property
    def name(self):
        """Gets the name of this Qubit.  # noqa: E501


        :return: The name of this Qubit.  # noqa: E501
        :rtype: int
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Qubit.


        :param name: The name of this Qubit.  # noqa: E501
        :type: int
        """

        self._name = name

    @property
    def pos_x(self):
        """Gets the pos_x of this Qubit.  # noqa: E501


        :return: The pos_x of this Qubit.  # noqa: E501
        :rtype: float
        """
        return self._pos_x

    @pos_x.setter
    def pos_x(self, pos_x):
        """Sets the pos_x of this Qubit.


        :param pos_x: The pos_x of this Qubit.  # noqa: E501
        :type: float
        """

        self._pos_x = pos_x

    @property
    def pos_y(self):
        """Gets the pos_y of this Qubit.  # noqa: E501


        :return: The pos_y of this Qubit.  # noqa: E501
        :rtype: float
        """
        return self._pos_y

    @pos_y.setter
    def pos_y(self, pos_y):
        """Sets the pos_y of this Qubit.


        :param pos_y: The pos_y of this Qubit.  # noqa: E501
        :type: float
        """

        self._pos_y = pos_y

    @property
    def real_qubit(self):
        """Gets the real_qubit of this Qubit.  # noqa: E501


        :return: The real_qubit of this Qubit.  # noqa: E501
        :rtype: int
        """
        return self._real_qubit

    @real_qubit.setter
    def real_qubit(self, real_qubit):
        """Sets the real_qubit of this Qubit.


        :param real_qubit: The real_qubit of this Qubit.  # noqa: E501
        :type: int
        """

        self._real_qubit = real_qubit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Qubit):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Qubit):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import openapi_client
from openapi_client.models.circuit import Circuit  # noqa: E501
from openapi_client.rest import ApiException

class TestCircuit(unittest.TestCase):
    """Circuit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Circuit
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = openapi_client.models.circuit.Circuit()  # noqa: E501
        if include_optional :
            return Circuit(
                body = '0', 
                depth = 56, 
                jobs = [
                    openapi_client.models.job.Job(
                        allocations = openapi_client.models.job_allocations.Job_allocations(
                            allocated_circuits = [
                                openapi_client.models.allocation.Allocation(
                                    allocated_qubits = [
                                        56
                                        ], 
                                    depth = 56, 
                                    program = '0', 
                                    num_gates_double = 56, 
                                    num_gates_single = 56, 
                                    num_measurements = 56, 
                                    num_swaps = 56, )
                                ], 
                            input_parameters = openapi_client.models.compilation_parameters.CompilationParameters(
                                compilation_type = '0', 
                                num_allocations = 56, ), 
                            language = '0', 
                            runtime = 1.337, ), 
                        cancelling = True, 
                        costs = openapi_client.models.job_costs.Job_costs(
                            reservation = 1.337, ), 
                        errors = [
                            openapi_client.models.job_errors.Job_errors(
                                error_code = '0', 
                                error_message = '0', )
                            ], 
                        execution = openapi_client.models.job_execution.Job_execution(
                            parameters = openapi_client.models.execution_parameters.ExecutionParameters(
                                num_shots = 56, 
                                output_type = '0', ), 
                            results = openapi_client.models.execution_results.ExecutionResults(
                                real = openapi_client.models.results_data.ResultsData(
                                    empirical_sso = 1.337, 
                                    end_datetime = '0', 
                                    measurements = openapi_client.models.results_data_measurements.ResultsData_measurements(
                                        raw = [
                                            [
                                                [
                                                    56
                                                    ]
                                                ]
                                            ], 
                                        weighted_combination = {
                                            'key' : 1.337
                                            }, ), 
                                    runtime = 1.337, 
                                    start_datetime = '0', ), 
                                simulated = openapi_client.models.results_data.ResultsData(
                                    empirical_sso = 1.337, 
                                    end_datetime = '0', 
                                    runtime = 1.337, 
                                    start_datetime = '0', ), ), ), 
                        id = '0', 
                        reservation = openapi_client.models.reservation.Reservation(
                            end_datetime = '0', 
                            id = '0', 
                            price = 1.337, 
                            start_datetime = '0', 
                            their_id = '0', ), 
                        target = openapi_client.models.owner_details.OwnerDetails(
                            owners = {
                                'key' : openapi_client.models.owner_details_owners.OwnerDetails_owners(
                                    devices = {
                                        'key' : openapi_client.models.device_details.DeviceDetails(
                                            device_id = '0', 
                                            display_name = '0', 
                                            gates = [
                                                openapi_client.models.gate.Gate(
                                                    fidelity = 1.337, 
                                                    qubit_from = openapi_client.models.qubit.Qubit(
                                                        fidelity_rotation = 1.337, 
                                                        last_reported_fidelity_rotation_datetime = '0', 
                                                        name = 56, 
                                                        pos_x = 1.337, 
                                                        pos_y = 1.337, 
                                                        real_qubit = 56, ), 
                                                    qubit_to = openapi_client.models.qubit.Qubit(
                                                        fidelity_rotation = 1.337, 
                                                        last_reported_fidelity_rotation_datetime = '0', 
                                                        name = 56, 
                                                        pos_x = 1.337, 
                                                        pos_y = 1.337, 
                                                        real_qubit = 56, ), 
                                                    gate_type = '0', )
                                                ], 
                                            is_simulator = True, 
                                            last_calibration = '0', 
                                            max_shots = 56, 
                                            next_available_time = '0', 
                                            price = 1.337, 
                                            t1 = 1.337, 
                                            t2 = 1.337, )
                                        }, )
                                }, ), )
                    ], 
                language = '0', 
                name = '0', 
                num_gates_double = 56, 
                num_gates_single = 56, 
                num_measurements = 56, 
                num_swaps = 56
            )
        else :
            return Circuit(
                body = '0',
                jobs = [
                    openapi_client.models.job.Job(
                        allocations = openapi_client.models.job_allocations.Job_allocations(
                            allocated_circuits = [
                                openapi_client.models.allocation.Allocation(
                                    allocated_qubits = [
                                        56
                                        ], 
                                    depth = 56, 
                                    program = '0', 
                                    num_gates_double = 56, 
                                    num_gates_single = 56, 
                                    num_measurements = 56, 
                                    num_swaps = 56, )
                                ], 
                            input_parameters = openapi_client.models.compilation_parameters.CompilationParameters(
                                compilation_type = '0', 
                                num_allocations = 56, ), 
                            language = '0', 
                            runtime = 1.337, ), 
                        cancelling = True, 
                        costs = openapi_client.models.job_costs.Job_costs(
                            reservation = 1.337, ), 
                        errors = [
                            openapi_client.models.job_errors.Job_errors(
                                error_code = '0', 
                                error_message = '0', )
                            ], 
                        execution = openapi_client.models.job_execution.Job_execution(
                            parameters = openapi_client.models.execution_parameters.ExecutionParameters(
                                num_shots = 56, 
                                output_type = '0', ), 
                            results = openapi_client.models.execution_results.ExecutionResults(
                                real = openapi_client.models.results_data.ResultsData(
                                    empirical_sso = 1.337, 
                                    end_datetime = '0', 
                                    measurements = openapi_client.models.results_data_measurements.ResultsData_measurements(
                                        raw = [
                                            [
                                                [
                                                    56
                                                    ]
                                                ]
                                            ], 
                                        weighted_combination = {
                                            'key' : 1.337
                                            }, ), 
                                    runtime = 1.337, 
                                    start_datetime = '0', ), 
                                simulated = openapi_client.models.results_data.ResultsData(
                                    empirical_sso = 1.337, 
                                    end_datetime = '0', 
                                    runtime = 1.337, 
                                    start_datetime = '0', ), ), ), 
                        id = '0', 
                        reservation = openapi_client.models.reservation.Reservation(
                            end_datetime = '0', 
                            id = '0', 
                            price = 1.337, 
                            start_datetime = '0', 
                            their_id = '0', ), 
                        target = openapi_client.models.owner_details.OwnerDetails(
                            owners = {
                                'key' : openapi_client.models.owner_details_owners.OwnerDetails_owners(
                                    devices = {
                                        'key' : openapi_client.models.device_details.DeviceDetails(
                                            device_id = '0', 
                                            display_name = '0', 
                                            gates = [
                                                openapi_client.models.gate.Gate(
                                                    fidelity = 1.337, 
                                                    qubit_from = openapi_client.models.qubit.Qubit(
                                                        fidelity_rotation = 1.337, 
                                                        last_reported_fidelity_rotation_datetime = '0', 
                                                        name = 56, 
                                                        pos_x = 1.337, 
                                                        pos_y = 1.337, 
                                                        real_qubit = 56, ), 
                                                    qubit_to = openapi_client.models.qubit.Qubit(
                                                        fidelity_rotation = 1.337, 
                                                        last_reported_fidelity_rotation_datetime = '0', 
                                                        name = 56, 
                                                        pos_x = 1.337, 
                                                        pos_y = 1.337, 
                                                        real_qubit = 56, ), 
                                                    gate_type = '0', )
                                                ], 
                                            is_simulator = True, 
                                            last_calibration = '0', 
                                            max_shots = 56, 
                                            next_available_time = '0', 
                                            price = 1.337, 
                                            t1 = 1.337, 
                                            t2 = 1.337, )
                                        }, )
                                }, ), )
                    ],
                language = '0',
        )

    def testCircuit(self):
        """Test Circuit"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import openapi_client
from openapi_client.api.info_api import InfoApi  # noqa: E501
from openapi_client.rest import ApiException


class TestInfoApi(unittest.TestCase):
    """InfoApi unit test stubs"""

    def setUp(self):
        self.api = openapi_client.api.info_api.InfoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_info_execution_types_get(self):
        """Test case for info_execution_types_get

        get list of possible execution types for jobs  # noqa: E501
        """
        pass

    def test_info_languages_get(self):
        """Test case for info_languages_get

        get list of languages in database  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import openapi_client
from openapi_client.api.device_rankings_api import DeviceRankingsApi  # noqa: E501
from openapi_client.rest import ApiException


class TestDeviceRankingsApi(unittest.TestCase):
    """DeviceRankingsApi unit test stubs"""

    def setUp(self):
        self.api = openapi_client.api.device_rankings_api.DeviceRankingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_devices_list_get(self):
        """Test case for devices_list_get

        retrieves list of potential devices to run the circuit on  # noqa: E501
        """
        pass

    def test_devices_list_stream_get(self):
        """Test case for devices_list_stream_get

        streams device detail updates  # noqa: E501
        """
        pass

    def test_devices_next_available_get(self):
        """Test case for devices_next_available_get

        retrieves list of next avaiable times for devices  # noqa: E501
        """
        pass

    def test_rankings_list_post(self):
        """Test case for rankings_list_post

        retrieves predicted device rankings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class CompiledCircuit(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'compiled_circuit': 'str',
        'depth': 'int',
        'num_measurements': 'int',
        'num_one_qubit_gates': 'int',
        'num_swaps': 'int',
        'num_two_qubit_gates': 'int',
        'qubits': 'list[int]'
    }

    attribute_map = {
        'compiled_circuit': 'compiledCircuit',
        'depth': 'depth',
        'num_measurements': 'numMeasurements',
        'num_one_qubit_gates': 'numOneQubitGates',
        'num_swaps': 'numSwaps',
        'num_two_qubit_gates': 'numTwoQubitGates',
        'qubits': 'qubits'
    }

    def __init__(self, compiled_circuit=None, depth=None, num_measurements=None, num_one_qubit_gates=None, num_swaps=None, num_two_qubit_gates=None, qubits=None, local_vars_configuration=None):  # noqa: E501
        """CompiledCircuit - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._compiled_circuit = None
        self._depth = None
        self._num_measurements = None
        self._num_one_qubit_gates = None
        self._num_swaps = None
        self._num_two_qubit_gates = None
        self._qubits = None
        self.discriminator = None

        if compiled_circuit is not None:
            self.compiled_circuit = compiled_circuit
        if depth is not None:
            self.depth = depth
        if num_measurements is not None:
            self.num_measurements = num_measurements
        if num_one_qubit_gates is not None:
            self.num_one_qubit_gates = num_one_qubit_gates
        if num_swaps is not None:
            self.num_swaps = num_swaps
        if num_two_qubit_gates is not None:
            self.num_two_qubit_gates = num_two_qubit_gates
        if qubits is not None:
            self.qubits = qubits

    @property
    def compiled_circuit(self):
        """Gets the compiled_circuit of this CompiledCircuit.  # noqa: E501


        :return: The compiled_circuit of this CompiledCircuit.  # noqa: E501
        :rtype: str
        """
        return self._compiled_circuit

    @compiled_circuit.setter
    def compiled_circuit(self, compiled_circuit):
        """Sets the compiled_circuit of this CompiledCircuit.


        :param compiled_circuit: The compiled_circuit of this CompiledCircuit.  # noqa: E501
        :type: str
        """

        self._compiled_circuit = compiled_circuit

    @property
    def depth(self):
        """Gets the depth of this CompiledCircuit.  # noqa: E501


        :return: The depth of this CompiledCircuit.  # noqa: E501
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this CompiledCircuit.


        :param depth: The depth of this CompiledCircuit.  # noqa: E501
        :type: int
        """

        self._depth = depth

    @property
    def num_measurements(self):
        """Gets the num_measurements of this CompiledCircuit.  # noqa: E501


        :return: The num_measurements of this CompiledCircuit.  # noqa: E501
        :rtype: int
        """
        return self._num_measurements

    @num_measurements.setter
    def num_measurements(self, num_measurements):
        """Sets the num_measurements of this CompiledCircuit.


        :param num_measurements: The num_measurements of this CompiledCircuit.  # noqa: E501
        :type: int
        """

        self._num_measurements = num_measurements

    @property
    def num_one_qubit_gates(self):
        """Gets the num_one_qubit_gates of this CompiledCircuit.  # noqa: E501


        :return: The num_one_qubit_gates of this CompiledCircuit.  # noqa: E501
        :rtype: int
        """
        return self._num_one_qubit_gates

    @num_one_qubit_gates.setter
    def num_one_qubit_gates(self, num_one_qubit_gates):
        """Sets the num_one_qubit_gates of this CompiledCircuit.


        :param num_one_qubit_gates: The num_one_qubit_gates of this CompiledCircuit.  # noqa: E501
        :type: int
        """

        self._num_one_qubit_gates = num_one_qubit_gates

    @property
    def num_swaps(self):
        """Gets the num_swaps of this CompiledCircuit.  # noqa: E501


        :return: The num_swaps of this CompiledCircuit.  # noqa: E501
        :rtype: int
        """
        return self._num_swaps

    @num_swaps.setter
    def num_swaps(self, num_swaps):
        """Sets the num_swaps of this CompiledCircuit.


        :param num_swaps: The num_swaps of this CompiledCircuit.  # noqa: E501
        :type: int
        """

        self._num_swaps = num_swaps

    @property
    def num_two_qubit_gates(self):
        """Gets the num_two_qubit_gates of this CompiledCircuit.  # noqa: E501


        :return: The num_two_qubit_gates of this CompiledCircuit.  # noqa: E501
        :rtype: int
        """
        return self._num_two_qubit_gates

    @num_two_qubit_gates.setter
    def num_two_qubit_gates(self, num_two_qubit_gates):
        """Sets the num_two_qubit_gates of this CompiledCircuit.


        :param num_two_qubit_gates: The num_two_qubit_gates of this CompiledCircuit.  # noqa: E501
        :type: int
        """

        self._num_two_qubit_gates = num_two_qubit_gates

    @property
    def qubits(self):
        """Gets the qubits of this CompiledCircuit.  # noqa: E501


        :return: The qubits of this CompiledCircuit.  # noqa: E501
        :rtype: list[int]
        """
        return self._qubits

    @qubits.setter
    def qubits(self, qubits):
        """Sets the qubits of this CompiledCircuit.


        :param qubits: The qubits of this CompiledCircuit.  # noqa: E501
        :type: list[int]
        """

        self._qubits = qubits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompiledCircuit):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompiledCircuit):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class CircuitInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'matrix': 'list[list[float]]',
        'num_nodes': 'int',
        'prob_edge': 'float',
        'num_iterations': 'int',
        'starting_vectors': 'list[list[float]]'
    }

    attribute_map = {
        'matrix': 'matrix',
        'num_nodes': 'numNodes',
        'prob_edge': 'probEdge',
        'num_iterations': 'numIterations',
        'starting_vectors': 'startingVectors'
    }

    def __init__(self, matrix=None, num_nodes=None, prob_edge=None, num_iterations=None, starting_vectors=None, local_vars_configuration=None):  # noqa: E501
        """CircuitInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._matrix = None
        self._num_nodes = None
        self._prob_edge = None
        self._num_iterations = None
        self._starting_vectors = None
        self.discriminator = None

        if matrix is not None:
            self.matrix = matrix
        if num_nodes is not None:
            self.num_nodes = num_nodes
        if prob_edge is not None:
            self.prob_edge = prob_edge
        if num_iterations is not None:
            self.num_iterations = num_iterations
        if starting_vectors is not None:
            self.starting_vectors = starting_vectors

    @property
    def matrix(self):
        """Gets the matrix of this CircuitInput.  # noqa: E501


        :return: The matrix of this CircuitInput.  # noqa: E501
        :rtype: list[list[float]]
        """
        return self._matrix

    @matrix.setter
    def matrix(self, matrix):
        """Sets the matrix of this CircuitInput.


        :param matrix: The matrix of this CircuitInput.  # noqa: E501
        :type: list[list[float]]
        """

        self._matrix = matrix

    @property
    def num_nodes(self):
        """Gets the num_nodes of this CircuitInput.  # noqa: E501


        :return: The num_nodes of this CircuitInput.  # noqa: E501
        :rtype: int
        """
        return self._num_nodes

    @num_nodes.setter
    def num_nodes(self, num_nodes):
        """Sets the num_nodes of this CircuitInput.


        :param num_nodes: The num_nodes of this CircuitInput.  # noqa: E501
        :type: int
        """

        self._num_nodes = num_nodes

    @property
    def prob_edge(self):
        """Gets the prob_edge of this CircuitInput.  # noqa: E501


        :return: The prob_edge of this CircuitInput.  # noqa: E501
        :rtype: float
        """
        return self._prob_edge

    @prob_edge.setter
    def prob_edge(self, prob_edge):
        """Sets the prob_edge of this CircuitInput.


        :param prob_edge: The prob_edge of this CircuitInput.  # noqa: E501
        :type: float
        """

        self._prob_edge = prob_edge

    @property
    def num_iterations(self):
        """Gets the num_iterations of this CircuitInput.  # noqa: E501


        :return: The num_iterations of this CircuitInput.  # noqa: E501
        :rtype: int
        """
        return self._num_iterations

    @num_iterations.setter
    def num_iterations(self, num_iterations):
        """Sets the num_iterations of this CircuitInput.


        :param num_iterations: The num_iterations of this CircuitInput.  # noqa: E501
        :type: int
        """

        self._num_iterations = num_iterations

    @property
    def starting_vectors(self):
        """Gets the starting_vectors of this CircuitInput.  # noqa: E501


        :return: The starting_vectors of this CircuitInput.  # noqa: E501
        :rtype: list[list[float]]
        """
        return self._starting_vectors

    @starting_vectors.setter
    def starting_vectors(self, starting_vectors):
        """Sets the starting_vectors of this CircuitInput.


        :param starting_vectors: The starting_vectors of this CircuitInput.  # noqa: E501
        :type: list[list[float]]
        """

        self._starting_vectors = starting_vectors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CircuitInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CircuitInput):
            return True

        return self.to_dict() != other.to_dict()
